[Zope3-checkins] CVS: Zope3/lib/python/Zope/App/Workflow/Stateful - IProcessDefinition.py:1.1.2.2 IProcessInstance.py:1.1.2.2 IState.py:1.1.2.2 ITransition.py:1.1.2.2 ProcessDefinition.py:1.1.2.2

Grégoire Weber zope@i-con.ch
Thu, 5 Dec 2002 11:00:16 -0500


Update of /cvs-repository/Zope3/lib/python/Zope/App/Workflow/Stateful
In directory cvs.zope.org:/tmp/cvs-serv11528/Stateful

Modified Files:
      Tag: sprintathon-wf-branch
	IProcessDefinition.py IProcessInstance.py IState.py 
	ITransition.py ProcessDefinition.py 
Log Message:
corrected typos


=== Zope3/lib/python/Zope/App/Workflow/Stateful/IProcessDefinition.py 1.1.2.1 => 1.1.2.2 ===
--- Zope3/lib/python/Zope/App/Workflow/Stateful/IProcessDefinition.py:1.1.2.1	Thu Dec  5 10:50:37 2002
+++ Zope3/lib/python/Zope/App/Workflow/Stateful/IProcessDefinition.py	Thu Dec  5 11:00:14 2002
@@ -12,7 +12,7 @@
 #
 ##############################################################################
 
-"""Interfaces for statefull workflow process definition.
+"""Interfaces for stateful workflow process definition.
 
 $Id$
 """
@@ -24,7 +24,7 @@
      import IWorkflowProcessDefinition
 
 class IProcessDefinition(IWorkflowProcessDefinition):
-    """Interface for statefull workflow process definition."""
+    """Interface for stateful workflow process definition."""
 
     def addState(name, state):
         """Add a IState to the process definition"""


=== Zope3/lib/python/Zope/App/Workflow/Stateful/IProcessInstance.py 1.1.2.1 => 1.1.2.2 ===
--- Zope3/lib/python/Zope/App/Workflow/Stateful/IState.py:1.1.2.1	Thu Dec  5 10:50:37 2002
+++ Zope3/lib/python/Zope/App/Workflow/Stateful/IState.py	Thu Dec  5 11:00:14 2002
@@ -12,7 +12,7 @@
 #
 ##############################################################################
 
-"""Interface for state of a statefull workflow process definition.
+"""Interface for state of a stateful workflow process definition.
 
 $Id$
 """
@@ -22,7 +22,7 @@
 
 
 class IState(Interface):
-    """Interface for state of a statefull workflow process definition."""
+    """Interface for state of a stateful workflow process definition."""
 
     def addOutgoingTransition(name):
         """Add an outgoing transition."""


=== Zope3/lib/python/Zope/App/Workflow/Stateful/ITransition.py 1.1.2.1 => 1.1.2.2 ===
--- Zope3/lib/python/Zope/App/Workflow/Stateful/ITransition.py:1.1.2.1	Thu Dec  5 10:50:37 2002
+++ Zope3/lib/python/Zope/App/Workflow/Stateful/ITransition.py	Thu Dec  5 11:00:14 2002
@@ -21,7 +21,7 @@
 from Interface.Attribute import Attribute
 
 class ITransition(Interface):
-    """Interface for a statefull workflow transition."""
+    """Interface for a stateful workflow transition."""
 
     destinationState = Attribute("name of the destination state")
     condition = Attribute("""The condition that has evaluated to decide if \


=== Zope3/lib/python/Zope/App/Workflow/Stateful/ProcessDefinition.py 1.1.2.1 => 1.1.2.2 ===
--- Zope3/lib/python/Zope/App/Workflow/Stateful/IProcessInstance.py:1.1.2.1	Thu Dec  5 10:50:37 2002
+++ Zope3/lib/python/Zope/App/Workflow/Stateful/IProcessInstance.py	Thu Dec  5 11:00:14 2002
@@ -12,7 +12,7 @@
 #
 ##############################################################################
 
 """Interface for statefull workflow process instances.
 
 $Id$
 """
@@ -28,7 +28,7 @@
     """Workflow process instance.
 
     Represents the instance of a process defined by a
-    StatefullProcessDefinition.
+    StatefulProcessDefinition.
     """
 
     def getOutgoingTransitions():
@@ -12,7 +12,7 @@
 ##############################################################################
 
-"""Interface for statefull workflow process instances.
+"""Interface for stateful workflow process instances.
 
 $Id$


=== Zope3/lib/python/Zope/App/Workflow/Stateful/IState.py 1.1.2.1 => 1.1.2.2 ===
--- Zope3/lib/python/Zope/App/Workflow/Stateful/ProcessDefinition.py:1.1.2.1	Thu Dec  5 10:50:37 2002
+++ Zope3/lib/python/Zope/App/Workflow/Stateful/ProcessDefinition.py	Thu Dec  5 11:00:14 2002
@@ -12,7 +12,7 @@
 #
 ##############################################################################
 
 """Statefull workflow process definition.
 
 $Id$
 """
@@ -20,7 +20,7 @@
 from Persistence import Persistent
 from Zope.App.Workflow.IWorkflowProcessDefinition import \
      IWorkflowProcessDefinition
-from Zope.App.Workflow.Statefull.IProcessDefinition import \
+from Zope.App.Workflow.Stateful.IProcessDefinition import \
      IProcessDefinition
 
 ### GWr: cleanup
@@ -40,7 +40,7 @@
 
 
 class ProcessDefinition(Persistent):
     """Statefull workflow process definition."""
 
     __implements__ = IProcessDefinition
 
@@ -51,7 +51,7 @@
 
     ############################################################
     # Implementation methods for interface
-    # Zope.App.Workflow.IStatefullProcessDefinition
+    # Zope.App.Workflow.IStatefulProcessDefinition
 
     def createProcessInstance(self):
         return None
@@ -12,7 +12,7 @@
 ##############################################################################
 
-"""Statefull workflow process definition.
+"""Stateful workflow process definition.
 
 $Id$
@@ -40,7 +40,7 @@
 
 class ProcessDefinition(Persistent):
-    """Statefull workflow process definition."""
+    """Stateful workflow process definition."""
 
     __implements__ = IProcessDefinition